@@ -1,5 +1,10 @@
 import requests,json,time
 
+#Created and maintained by Kristan Smout
+#Github URL = https://github.com/KristanSmout/RobloxPyOfficial
+
+Version = '0.0.94'
+
 
 APIURL = "https://api.roblox.com/"
 SettingsURL = "https://www.roblox.com/my/settings/json"
@@ -10,12 +15,25 @@ InventoryURL = "https://inventory.roblox.com/v2/assets/"
 GamesURL = "https://games.roblox.com/v1/"
 RBXCityInventURL = "https://data.rbxcity.com/user-inventories/fetch/history/"
 UserAPI = APIURL + "users/"
+UserAPIV1 = APIURL + "v1/users/"
 GroupAPI = APIURL + "groups/"
 GroupAPIV1 = "https://groups.roblox.com/v1/groups/"
 
 
+#Internal
+def CheckForUpdate():
+    response = requests.get('https://pypi.org/pypi/robloxpy/json')
+    LatestVersion = response.json()['info']['version']
+    if(Version == LatestVersion):
+        return 'You are up to date!'
+    else:
+        return f'Version {LatestVersion} is now availible'
 
-
+def CheckVersion():
+    return Version
+    
+def HowToUpdate():
+    return 'pip install robloxpy --upgrade'
 
 #region External
 
@@ -105,6 +123,15 @@ def GetUserTerribleDemandLimiteds(UserID):
     for data in response.json()['data']:
         return data['TerribleDemandItems']
 
+def DoesNameExist(UserName):
+    response = requests.get(UserAPI + 'get-by-username?username=' + str(UserName))
+    if('errorMessage' in response.text):
+        return ('Availible')
+    else:   
+        if(response.json()['Username'].lower() == UserName.lower()):
+            return('Unavailible')
+        elif (response.json()['Username'].lower() != UserName.lower()):
+            return('Availible')
 
 
 #endregion
@@ -229,8 +256,6 @@ def GetUniverseDislikes(UniverseID):
 
 #endregion
 
-
-
 #endregion
 
 
@@ -436,6 +461,19 @@ def ChangeGroupRank(Cookie,GroupID,UserID,roleId):
     session = SetCookie(Cookie)
     Patch = session.patch(GroupAPIV1 + str(GroupID) + '/users/' + str(UserID),data={'roleId' : roleId})
     return 'Sent'
+
+def ChangeGroupShout(Cookie,GroupID,StatusString):
+    session = SetCookie(Cookie)
+    Patch = session.patch(GroupAPIV1 + str(GroupID) + '/status',data={'message' : StatusString})
+    return 'Sent'
+
+def ChangeGroupDescription(Cookie,GroupID,DescriptionString):
+    session = SetCookie(Cookie)
+    Patch = session.patch(GroupAPIV1 + str(GroupID) + '/description',data={'description' : DescriptionString})
+    return 'Sent'
+
+
+
 #endregion
 
 
